# BHC - Bayesian Hierarchical Clustering

:100: 

This is a project of implementing Beyesian Hierarchical Clustering in Python. 

Heller, Katherine A., and Zoubin Ghahramani. "Bayesian hierarchical clustering." Proceedings of the 22nd international conference on Machine learning. ACM, 2005.


### Data sets:
#### Data sets from the paper:
toyexample: handwriting number 0,2,4. It has 64 variables, containing information of handwriting.
   
   `dim`: (120, 64) <br/>

#### Data sets not in the paper:
iris: This is perhaps the best known database to be found in the pattern recognition literature. Fisher's paper is a classic in the field and is referenced frequently to this day. (See Duda & Hart, for example.) The data set contains 3 classes of 50 instances each, where each class refers to a type of iris plant. One class is linearly separable from the other 2; the latter are NOT linearly separable from each other.  <br/>
   
   `dim`: (150, 5) <br/>
